#!/usr/bin/env python

import sys
import time

def generate_html(code_contributors, non_code_contributors, args):
    repo_name = args.repo_name

    if not args.show_contributors and len(non_code_contributors) == 0:
      print("No non-code contributors for %s. No HTML output being generated." % repo_name)
      sys.exit(0)

    html_file = "%s_contrib.html" % repo_name.replace("/", "_")
    f = open(html_file, "w")

    f.write("<meta charset='UTF-8'>")
    f.write("<style>div.contributors > div {display:inline-block; padding: 10px;} div.contributors > div > div { text-align: center; padding: 5px} footer {padding-top: 40px}</style>")
    f.write("<h1>Non-code contributions for %s</h1>" % repo_name)
    f.write("<div class='contributors'>")

    for user in non_code_contributors: 
      f.write(display_user_html(user, args))
    f.write("</div>")
  
    if args.show_contributors:
      f.write("<h1>Code contributions for %s</h1>\n" % repo_name)
      f.write("<div class='contributors'>")
      for user in code_contributors:
        f.write(display_user_html(user, args))
      f.write("</div>")

    f.write("<footer>")
    gen_time = time.strftime('%Y-%m-%d %H:%M:%S %Z', time.gmtime())
    f.write("Generated by <a href='https://github.com/LABHR/octohatrack'>octohatrack</a> at %s" % gen_time)
    if args.limit > 0:
      f.write("<br>Results limited to the most recent %d issues/pull requests." % args.limit)
    f.write("</footer>")
    
    f.close()

    print("\nGenerated HTML representation, saved to %s" % html_file)

def display_user_html(user, args):
    url = "https://github.com/%s/issues?q=involves:%s" % (args.repo_name, user["user_name"])
    html = ("<div><a href='%s'><img src='%s' width='128' alt='%s'></a><div>%s</div></div>\n" %
        (url, user["avatar"], user["user_name"], user['name']))
    return html
